==> newsstar-1.2.2.tar.gz: newsstar-1.2.2/src/local.c <==
/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

#include <netinet/in.h>

#include "local.h"
#include "main.h"
#include "nntp.h"
#include "parserc.h"

static char *local_server = NULL;
static long int local_port = -1;
static char *local_user = NULL;
static char *local_passwd = NULL;

static char *histcheck_server = NULL;
static long int histcheck_port = -1;
static char *histcheck_user = NULL;
static char *histcheck_passwd = NULL;

rw_buf *local_buf = NULL;

static void local_close_buf(void)
{
    if (main_normal_exit && local_buf)
    {
	rw_write_line(local_buf, "QUIT");
	nntp_check_response(local_buf, _("Bad response to QUIT"), "2",
		deblog_Level_Critical);
	rw_close_and_free(local_buf);
	local_buf = NULL;
    }
}

void local_config_init(void)
{
    parserc_register_string("histcheck_server", &histcheck_server);
    parserc_register_int("histcheck_port", &histcheck_port);
    parserc_register_string("histcheck_user", &histcheck_user);
    parserc_register_string("histcheck_passwd", &histcheck_passwd);

    parserc_register_string("local_server", &local_server);
    parserc_register_int("local_port", &local_port);
    parserc_register_string("local_user", &local_user);
    parserc_register_string("local_passwd", &local_passwd);
}

static void local_histcheck_warn(void)
{
    static BOOL warned = FALSE;

    if (!warned)
    {
	deblog_warning(_("histcheck_ option keywords are obsolete\n"));
	deblog_warning(
		_("Please replace with the corresponding local_ keyword(s)\n"));
	warned = TRUE;
    }
}

void local_init(void)
{
    char *dotquad;
    static BOOL initialised = FALSE;

    if (initialised)
	return;
    initialised = TRUE;
    atexit(local_close_buf);
    if (!local_server && histcheck_server)
    {
	local_server = histcheck_server;
	local_histcheck_warn();
    }
    if (!local_user && histcheck_user)
    {
	local_user = histcheck_user;
	local_histcheck_warn();
    }
    if (!local_passwd && histcheck_passwd)
    {
	local_passwd = histcheck_passwd;
	local_histcheck_warn();
    }
    if (local_port == -1 && histcheck_port != -1)
    {
	local_port = histcheck_port;
	local_histcheck_warn();
    }
    if (local_port == -1)
	local_port = 119;
    deblog_info(_("Establishing local connection to %s\n"),
	    local_server ? local_server : "localhost");
    dotquad = nntp_resolve_address(local_server ? local_server :
	    "localhost");
    if (!dotquad)
    {
	deblog_error(_("Can't find address of local server %s\n"),
		local_server);
    }
    local_buf = nntp_connect(dotquad, htons(local_port), -1,
	    maincf_get_local_ssl());
    if (!local_buf)
	deblog_error(_("Unable to connect to local server\n"));
    if (local_user && nntp_authenticate(local_buf, local_user, local_passwd))
    {
	deblog_error(_("Unable to authenticate to local server\n"));
    }
}

==> newsstar-1.3.2.tar.gz: newsstar-1.3.2/src/local.c <==
/*
    newsstar - advanced news fetcher
    Copyright (C) 2001-2002 Tony Houghton <h@realh.co.uk>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

#include <netinet/in.h>

#include "local.h"
#include "main.h"
#include "nntp.h"
#include "parserc.h"

static char *local_server = NULL;
static long int local_port = -1;
static char *local_user = NULL;
static char *local_passwd = NULL;

static char *histcheck_server = NULL;
static long int histcheck_port = -1;
static char *histcheck_user = NULL;
static char *histcheck_passwd = NULL;

rw_buf *local_buf = NULL;

static void local_close_buf(void)
{
    if (main_normal_exit && local_buf)
    {
	rw_write_line(local_buf, "QUIT");
	nntp_check_response(local_buf, "localhost",
		_("Bad response to QUIT"), "2", deblog_Level_Critical);
	rw_close_and_free(local_buf);
	local_buf = NULL;
    }
}

void local_config_init(void)
{
    parserc_register_string("histcheck_server", &histcheck_server);
    parserc_register_int("histcheck_port", &histcheck_port);
    parserc_register_string("histcheck_user", &histcheck_user);
    parserc_register_string("histcheck_passwd", &histcheck_passwd);

    parserc_register_string("local_server", &local_server);
    parserc_register_int("local_port", &local_port);
    parserc_register_string("local_user", &local_user);
    parserc_register_string("local_passwd", &local_passwd);
}

static void local_histcheck_warn(void)
{
    static BOOL warned = FALSE;

    if (!warned)
    {
	deblog_warning(_("histcheck_ option keywords are obsolete\n"));
	deblog_warning(
		_("Please replace with the corresponding local_ keyword(s)\n"));
	warned = TRUE;
    }
}

void local_init(void)
{
    char *dotquad;
    static BOOL initialised = FALSE;

    if (initialised)
	return;
    initialised = TRUE;
    atexit(local_close_buf);
    if (!local_server && histcheck_server)
    {
	local_server = histcheck_server;
	local_histcheck_warn();
    }
    if (!local_user && histcheck_user)
    {
	local_user = histcheck_user;
	local_histcheck_warn();
    }
    if (!local_passwd && histcheck_passwd)
    {
	local_passwd = histcheck_passwd;
	local_histcheck_warn();
    }
    if (local_port == -1 && histcheck_port != -1)
    {
	local_port = histcheck_port;
	local_histcheck_warn();
    }
    if (local_port == -1)
	local_port = 119;
    deblog_info(_("Establishing local connection to %s\n"),
	    local_server ? local_server : "localhost");
    dotquad = nntp_resolve_address(local_server ? local_server :
	    "localhost");
    if (!dotquad)
    {
	deblog_error(_("Can't find address of local server %s\n"),
		local_server);
    }
    local_buf = nntp_connect("localhost", dotquad, htons(local_port), -1,
	    maincf_get_local_ssl());
    if (!local_buf)
	deblog_error(_("Unable to connect to local server\n"));
    if (local_user && nntp_authenticate(local_buf, "localhost",
		local_user, local_passwd))
    {
	deblog_error(_("Unable to authenticate to local server\n"));
    }
}
